/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    adhesive_play_box_physics.cc
 * @brief   AdhesivePlayBoxPhysics class definition.
 * @date    2008
 *
 */

#include <string>

#include <Inventor/SbLinear.h>

#include "adhesive_play_box_physics.h"
#include "factories/factory_play_box_physics.h"

namespace
{
	// Motion vector (go straight forward to the rear wall)
	const SbVec3f STRAIGHT_FORWARD = SbVec3f(0, 0, 1);
}

void AdhesivePlayBoxPhysics::fixHorizontalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	bubble->setPosition(SbVec3f(
				position[0], borderPos, position[2]));

	// Correct the motion vector
	bubble->setMotionVector(STRAIGHT_FORWARD);
}

void AdhesivePlayBoxPhysics::fixVerticalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	bubble->setPosition(SbVec3f(
				borderPos, position[1], position[2]));

	// Correct the motion vector
	bubble->setMotionVector(STRAIGHT_FORWARD);
}

void AdhesivePlayBoxPhysics::fixLeftWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void AdhesivePlayBoxPhysics::fixRightWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void AdhesivePlayBoxPhysics::fixTopWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

void AdhesivePlayBoxPhysics::fixBottomWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

AdhesivePlayBoxPhysics::AdhesivePlayBoxPhysics()
{
}

AdhesivePlayBoxPhysics::~AdhesivePlayBoxPhysics()
{
}

void AdhesivePlayBoxPhysics::timeUpdate(float /*dt*/)
{
	// Do nothing
}

// Functions and constants needed by Factories::FactoryPlayBoxPhysics
namespace
{
	// AdhesivePlayBoxPhysics identifier for the play box physics factory
	const std::string BASIC_PLAY_BOX_PHYSICS_ID = "Adhesive";

	// Function that returns an instance of the AdhesivePlayBoxPhysics class
	PlayBoxPhysics *getBasicPlayBoxPhysicsInstance()
	{
		return new AdhesivePlayBoxPhysics::AdhesivePlayBoxPhysics();
	}

	// Register the selected play box physics at the play box physics factory
	const bool BASIC_PLAY_BOX_PHYSICS_REGISTERED = Factories::FactoryPlayBoxPhysics::instance().
		registerObject(BASIC_PLAY_BOX_PHYSICS_ID, getBasicPlayBoxPhysicsInstance);
}
