/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    avatar.cc
 * @brief   Implementation file for Avatar class
 * @date    2008
 *
 * This file includes the implementation of the Avatar abstract class, the
 * class encapsulating player avatar.
 */

#include <Inventor/nodes/SoMaterial.h>
#include <Inventor/nodes/SoCylinder.h>
#include <Inventor/nodes/SoCube.h>
#include <Inventor/nodes/SoTranslation.h>

#include "avatar.h"

Avatar::Avatar()
{
}

Avatar::~Avatar()
{
}

SoSeparator* Avatar::getBubbleHammer()
{
	// create the separator
	SoSeparator* hammerSep = new SoSeparator();

	// the material of the hammer head
	SoMaterial* hammerMaterial = new SoMaterial();
	hammerMaterial->diffuseColor.setValue(0.0f, 0.0f, 0.0f);
	hammerMaterial->specularColor.setValue(1.0f, 1.0f, 1.0f);
	hammerMaterial->shininess.setValue(1.0f);
	hammerSep->addChild(hammerMaterial);

	// move the hammer
	//SoTranslation* trans = new SoTranslation();
	//trans->translation.setValue(SbVec3f(0.0f, 5.0f, 0.0f));
	//hammerSep->addChild(trans);

	// rotate the hammer
	//SoRotationXYZ* rot = new SoRotationXYZ();
	//rot->axis.setValue(SoRotationXYZ::X);
	//rot->angle.setValue(M_PI / 2.0f);
	//hammerSep->addChild(rot);

	// create the hammer head
	SoCube* hammerHead = new SoCube();
	hammerHead->width.setValue(2.0f);
	hammerHead->height.setValue(2.0f);
	hammerHead->depth.setValue(4.0f);
	hammerSep->addChild(hammerHead);

	// the material of the hammer handle
	hammerMaterial = new SoMaterial();
	hammerMaterial->diffuseColor.setValue(0.75f, 0.34f, 0.0f);
	hammerSep->addChild(hammerMaterial);

	// move the hammer handle
	SoTranslation* trans = new SoTranslation();
	trans->translation.setValue(SbVec3f(0.0f, -2.9f, 0.0f));
	hammerSep->addChild(trans);

	// create the hammer handle
	SoCylinder* hammerHandle = new SoCylinder();
	hammerHandle->radius.setValue(0.6f);
	hammerHandle->height.setValue(8.0f);
	hammerSep->addChild(hammerHandle);

	return hammerSep;
}
