/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    basic_play_box_physics.cc
 * @brief   BasicPlayBoxPhysics class definition.
 * @date    2008
 *
 */

#include <string>

#include <Inventor/SbLinear.h>

#include "basic_play_box_physics.h"
#include "factories/factory_play_box_physics.h"

void BasicPlayBoxPhysics::fixHorizontalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	float correction = 2 * (position[1] - borderPos);
	bubble->setPosition(SbVec3f(
				position[0], position[1] - correction, position[2]));

	// Correct the motion vector
	const SbVec3f& motionVector = bubble->getMotionVector();
	bubble->setMotionVector(SbVec3f(
				motionVector[0], -motionVector[1], motionVector[2]));
}

void BasicPlayBoxPhysics::fixVerticalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	float correction = 2 * (position[0] - borderPos);
	bubble->setPosition(SbVec3f(
				position[0] - correction, position[1], position[2]));

	// Correct the motion vector
	const SbVec3f& motionVector = bubble->getMotionVector();
	bubble->setMotionVector(SbVec3f(
				-motionVector[0], motionVector[1], motionVector[2]));
}

void BasicPlayBoxPhysics::fixLeftWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void BasicPlayBoxPhysics::fixRightWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void BasicPlayBoxPhysics::fixTopWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

void BasicPlayBoxPhysics::fixBottomWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

BasicPlayBoxPhysics::BasicPlayBoxPhysics()
{
}

BasicPlayBoxPhysics::~BasicPlayBoxPhysics()
{
}

void BasicPlayBoxPhysics::timeUpdate(float /*dt*/)
{
	// Do nothing
}

// Functions and constants needed by Factories::FactoryPlayBoxPhysics
namespace
{
	// BasicPlayBoxPhysics identifier for the play box physics factory
	const std::string BASIC_PLAY_BOX_PHYSICS_ID = "Basic";

	// Function that returns an instance of the BasicPlayBoxPhysics class
	PlayBoxPhysics *getBasicPlayBoxPhysicsInstance()
	{
		return new BasicPlayBoxPhysics::BasicPlayBoxPhysics();
	}

	// Register the selected play box physics at the play box physics factory
	const bool BASIC_PLAY_BOX_PHYSICS_REGISTERED = Factories::FactoryPlayBoxPhysics::instance().
		registerObject(BASIC_PLAY_BOX_PHYSICS_ID, getBasicPlayBoxPhysicsInstance);
}
