/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    basic_play_box_physics.h
 * @brief   BasicPlayBoxPhysics class declaration.
 * @date    2008
 *
 */

#ifndef _BASIC_PLAY_BOX_PHYSICS_H_
#define _BASIC_PLAY_BOX_PHYSICS_H_

#include "play_box_physics.h"

/**
 * @brief Basic play box physics.
 *
 * Reference object (cannot be copied).
 */
class BasicPlayBoxPhysics: public PlayBoxPhysics
{
	private:

		// Disable copy constructor and assignment operator
		BasicPlayBoxPhysics(const BasicPlayBoxPhysics &);
		BasicPlayBoxPhysics & operator=(const BasicPlayBoxPhysics &);

		/**
		 * @brief Fixes a collision with top or bottom wall
		 */
		void fixHorizontalWallCollision(Bubble* bubble, float borderPos);

		/**
		 * @brief Fixes a collision with left or right wall
		 */
		void fixVerticalWallCollision(Bubble* bubble, float borderPos);

		// Override
		virtual void fixLeftWallCollision(Bubble* bubble, float borderPos);

		// Override
		virtual void fixRightWallCollision(Bubble* bubble, float borderPos);

		// Override
		virtual void fixTopWallCollision(Bubble* bubble, float borderPos);

		// Override
		virtual void fixBottomWallCollision(Bubble* bubble, float borderPos);

	public:

		/**
		 * @brief Default constructor.
		 */
		BasicPlayBoxPhysics();

		/**
		 * @brief Destructor.
		 */
		virtual ~BasicPlayBoxPhysics();

		// Override
		virtual void timeUpdate(float dt);
};

#endif
