/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    bubble_generator.cc
 * @brief   BubbleGenerator class definition.
 * @date    2008
 *
 */

#include <cstdlib>
#include <algorithm>

#include "bubble_generator.h"
#include "fire_explosion.h"
#include "fading_explosion.h"

BubbleGenerator::BubbleGenerator(unsigned numberOfDifferentBubbles, Camera *camera):
	_availableBubbles(), _camera(camera),
	NUMBER_OF_DIFFERENT_BUBBLES(numberOfDifferentBubbles)
{
	generateAvailableBubbles();
}

BubbleGenerator::~BubbleGenerator()
{
	// Delete memory for all created bubbles
	for (BubbleContainerType::iterator iter = _availableBubbles.begin();
			iter != _availableBubbles.end(); ++iter) {
		delete *iter;
		*iter = 0;
	}
}

void BubbleGenerator::generateAvailableBubbles()
{
	SbColor bubbleColour;

	// Red bubble
	bubbleColour = SbColor(1.0f, 0.0f, 0.0f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));

	// Green bubble
	bubbleColour = SbColor(0.0f, 1.0f, 0.0f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));

	// Blue bubble
	bubbleColour = SbColor(0.0f, 0.0f, 1.0f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FadingExplosion(bubbleColour, _camera)));

	// Orange bubble
	bubbleColour = SbColor(1.0f, 0.64f, 0.0f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FadingExplosion(bubbleColour, _camera)));

	// Wheat bubble
	bubbleColour = SbColor(0.96f, 0.83f, 0.70f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));

	// Turquoise bubble
	bubbleColour = SbColor(0.25f, 0.875f, 0.8125f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));

	// Black bubble
	SbColor blackBubbleColor = SbColor(0.0f, 0.0f, 0.0f);
	_availableBubbles.push_back(new Bubble(blackBubbleColor,
		new FadingExplosion(blackBubbleColor, _camera)));

	// Purple bubble
	bubbleColour = SbColor(0.5f, 0.0f, 0.5f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));

	// Sienna bubble
	bubbleColour = SbColor(0.625f, 0.32f, 0.18f);
	_availableBubbles.push_back(new Bubble(bubbleColour,
		new FireExplosion(bubbleColour, _camera)));
}

unsigned BubbleGenerator::getRandomIndex() const
{
	const unsigned MAX_INDEX = std::min<unsigned>(NUMBER_OF_DIFFERENT_BUBBLES,
			_availableBubbles.size());
	return static_cast<unsigned>(MAX_INDEX * (std::rand() / (RAND_MAX + 1.0)));
}

Bubble *BubbleGenerator::generateBubble() const
{
	if (!_availableBubbles.empty()) {
		return _availableBubbles[getRandomIndex()]->clone();
	} else {
		return 0;
	}
}
