#
# qmake - project file
# Project: PGR 2008
# Authors:
#     Ondrej Lengal, xlenga00@stud.fit.vutbr.cz
#     Libor Polcak, xpolca03@stud.fit.vutbr.cz
#     Boris Prochazka, xproch63@stud.fit.vutbr.cz
#     Petr Zemek, xzemek02@stud.fit.vutbr.cz
#

PROJECT_NAME = bubble_shoooooter

#
# Configuration
#
CONFIG += qt
CONFIG += release
#CONFIG += debug
QT += core gui
CONFIG += object_with_source
#CONFIG += extra-warnings

#
# Paths
#
INCPATH += $$system(soqt-config --includedir) $$system(coin-config --includedir)
LIBS += $$system(soqt-config --ldflags) $$system(soqt-config --libs)
SRCDIR = .
DEPENDPATH += $$SRCDIR
INCLUDEPATH += $$SRCDIR
DESTDIR = .
TARGET = $$DESTDIR/$$PROJECT_NAME
OBJDIR = .

#
# Files
#
HEADERS = album_environment.h \
		avatar.h \
		basic_play_box_graphics.h \
		tunnel_play_box_graphics.h \
		basic_play_box_physics.h \
		adhesive_play_box_physics.h \
		bubble_field.h \
		bubble_generator.h \
		bubble.h \
		camera.h \
		convert.h \
		create_scene_parameters.h \
		difficulty_settings.h \
		environment.h \
		explosion.h \
		factories/factory_avatar.h \
		factories/factory_environment.h \
		factories/factory_play_box_graphics.h \
		factories/factory_play_box_physics.h \
		fading_explosion.h \
		fire_explosion.h \
		game_configuration.h \
		graphical_node.h \
		model_avatar.h \
		path_functions.h \
		play_box_graphics.h \
		play_box_physics.h \
		play_field.h \
		random_play_box_physics.h \
		scene_configuration.h \
		scene_creator.h \
		scene.h \
		snowman_avatar.h \
		space_environment.h \
		wire_environment.h \
		templates/callable_back.h \
		templates/factory.h \
		templates/observable.h \
		templates/observer.h \
		templates/singleton.h \
		texture_generator.h \
		time_updateable.h \
		gui/game_menu.h \
		gui/main_menu.h \
		gui/main_window.h \
		gui/render_window.h

SOURCES = album_environment.cc \
		avatar.cc \
		basic_play_box_graphics.cc \
		tunnel_play_box_graphics.cc \
		basic_play_box_physics.cc \
		adhesive_play_box_physics.cc \
		bubble.cc \
		bubble_field.cc \
		bubble_generator.cc \
		camera.cc \
		convert.cc \
		create_scene_parameters.cc \
		difficulty_settings.cc \
		environment.cc \
		explosion.cc \
		fading_explosion.cc \
		fire_explosion.cc \
		game_configuration.cc \
		graphical_node.cc \
		path_functions.cc \
		main.cc \
		model_avatar.cc \
		play_box_graphics.cc \
		play_box_physics.cc \
		play_field.cc \
		random_play_box_physics.cc \
		scene.cc \
		scene_configuration.cc \
		scene_creator.cc \
		snowman_avatar.cc \
		space_environment.cc \
		wire_environment.cc \
		texture_generator.cc \
		time_updateable.cc \
		gui/game_menu.cc \
		gui/main_menu.cc \
		gui/main_window.cc \
		gui/render_window.cc

#
# Extra warnings
#
# NOTE: The extracts are from the compiler help (manual pages):
extra-warnings:linux-g++ {

QMAKE_CXXFLAGS += -std=c++98 -pedantic
	# Require strict conformance with the C++98 standard.

QMAKE_CXXFLAGS += -Wnon-virtual-dtor
    # Warn when a class appears to be polymorphic, thereby requiring
    # a virtual destructor, yet it declares a non-virtual one.
    # This warning is enabled by -Wall.


QMAKE_CXXFLAGS += -Wreorder
	# Warn when the order of member initializers given in the code does
	# not match the order in which they must be executed.  For instance:
	#
	# 		struct A {
	# 			int i;
	# 			int j;
	# 			A(): j (0), i (1) { }
	# 		};
	#
	# The compiler will rearrange the member initializers for i and j to
	# match the declaration order of the members, emitting a warning
	# to that effect.  This warning is enabled by -Wall.

QMAKE_CXXFLAGS += -Weffc++
	# Warn about violations of the following style guidelines from Scott
	# Meyers’ Effective C++ book:
	#
	# *   Item 11:  Define a copy constructor and an assignment operator
	# 				for classes with dynamically allocated memory.
	#
	# *   Item 12:  Prefer initialization to assignment in constructors.
	#
	# *   Item 14:  Make destructors virtual in base classes.
	#
	# *   Item 15:  Have "operator=" return a reference to *this.
	#
	# *   Item 23:  Don’t try to return a reference when you must return
	# 				an object.
	#
	# Also warn about violations of the following style guidelines from
	# Scott Meyers’ More Effective C++ book:
	#
	# *   Item 6:  Distinguish between prefix and postfix forms of
	# 			increment and decrement operators.
	#
	# *   Item 7:  Never overload "&&", "||", or ",".
	#
	# When selecting this option, be aware that the standard library
	# headers do not obey all of these guidelines; use grep -v to filter
	# out those warnings.


QMAKE_CXXFLAGS += -Wold-style-cast
	# Warn if an old-style (C-style) cast to a non-void type is used within
	# a C++ program.  The new-style casts (dynamic_cast, static_cast, rein‐
	# terpret_cast, and const_cast) are less vulnerable to unintended
	# effects and much easier to search for.


QMAKE_CXXFLAGS += -Woverloaded-virtual
	# Warn when a function declaration hides virtual functions from
	# a base class.  For example, in:
	#
	#		struct A {
	#			virtual void f();
	#		};
	#
	#		struct B: public A {
	#			void f(int);
	#		};
	#
	# the "A" class version of "f" is hidden in "B", and code like:
	#
	#		B* b;
	#		b->f();
	#
	# will fail to compile.


QMAKE_CXXFLAGS += -Wsign-promo
	# Warn when overload resolution chooses a promotion from unsigned or
	# enumerated type to a signed type, over a conversion to an unsigned
	# type of the same size.  Previous versions of G++ would try to
	# preserve unsignedness, but the standard mandates the current behavior.
	#
	#		struct A {
	#			operator int ();
	#			A& operator = (int);
	#		};
	#
	#		main ()
	#		{
	#			A a,b;
	#			a = b;
	#		}
	#
	# In this example, G++ will synthesize a default
	# A& operator = (const A&);, while cfront will use
	# the user-defined operator =.

QMAKE_CXXFLAGS += -Wctor-dtor-privacy
	# Warn when a class seems unusable because all the constructors or
	# destructors in that class are private, and it has neither friends
	# nor public static member functions.

QMAKE_CXXFLAGS += -Wswitch-default
	# Warn whenever a "switch" statement does not have a "default" case.

QMAKE_CXXFLAGS += -Wswitch-enum
	# Warn whenever a "switch" statement has an index of enumerated type
	# and lacks a "case" for one or more of the named codes of that
	# enumeration. "case" labels outside the enumeration range also
	# provoke warnings when this option is used.

QMAKE_CXXFLAGS += -Wfloat-equal
	# Warn if floating point values are used in equality comparisons.

QMAKE_CXXFLAGS += -Wcast-qual
	# Warn whenever a pointer is cast so as to remove a type qualifier
	# from the target type.  For example, warn if a "const char *" is
	# cast to an ordinary "char *".

QMAKE_CXXFLAGS += -Wcast-align
	# Warn whenever a pointer is cast such that the required alignment
	# of the target is increased.  For example, warn if a "char *" is cast
	# to an "int *" on machines where integers can only be accessed
	# at two- or four-byte boundaries.

QMAKE_CXXFLAGS += -Wconversion
	# Warn if a prototype causes a type conversion that is different from
	# what would happen to the same argument in the absence of a prototype.
	# This includes conversions of fixed point to floating and vice versa,
	# and conversions changing the width or signedness of a fixed point
	# argument except when the same as the default promotion.
	#
	# Also, warn if a negative integer constant expression is implicitly
	# converted to an unsigned type.  For example, warn about
	# the assignment "x = -1" if "x" is unsigned. But do not warn about
	# explicit casts like "(unsigned) -1".

QMAKE_CXXFLAGS += -Wno-long-long
	# Inhibit 'ISO C++ does not support ‘long long’' message.

}
