/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    camera.cc
 * @brief   Camera class definition.
 * @date    2008
 *
 */

#include <cmath>

#include <Inventor/nodes/SoPerspectiveCamera.h>
#include <Inventor/nodes/SoGroup.h>
#include <Inventor/nodes/SoTranslation.h>
#include <Inventor/engines/SoElapsedTime.h>

#include "camera.h"

namespace
{
	const float MAX_ANGLE = 0.7f;
	const float MOUSE_SENSITIVITY = 200.0f;
}

Camera::Camera():
	Templates::Observable<Camera>(this), _rootNode(0), _rotX(0), _rotY(0),
	_angleX(0), _angleY(0), _maxAngleX(MAX_ANGLE),  _maxAngleY(MAX_ANGLE)
{
	_rootNode = new SoGroup();

	SoPerspectiveCamera* camera = new SoPerspectiveCamera();
	camera->farDistance.setValue(1000.0f);
	camera->position.setValue(0.0f, 0.0f, 0.0f);
	camera->pointAt(SbVec3f(0.0f, 0.0f, 1.0f), SbVec3f(0.0f, 1.0f, 0.0f));
	_rootNode->addChild(camera);

	SoTranslation* trans = new SoTranslation();
	trans->translation.setValue(0.0f, 0.0f, 14.0f);
	_rootNode->addChild(trans);

	_rotX = new SoRotationXYZ;
	_rotX->axis = SoRotationXYZ::X;
	_rotX->angle = _angleX;
	_rootNode->addChild(_rotX);

	_rotY = new SoRotationXYZ;
	_rotY->axis = SoRotationXYZ::Y;
	_rotY->angle = _angleY;
	_rootNode->addChild(_rotY);
}

Camera::~Camera() { }

void Camera::timeUpdate(float /*dt*/)
{
	// Do nothing
}

void Camera::updateView(short x, short y)
{
	_angleY += static_cast<float>(x)/MOUSE_SENSITIVITY;
	_rotY->angle = _angleY;

	_angleX += static_cast<float>(y)/MOUSE_SENSITIVITY;
	_rotX->angle = _angleX;

	if (std::abs(_angleX) > _maxAngleX) {
		if (_angleX > 0) {
			_angleX = _maxAngleX;
		} else {
			_angleX = -_maxAngleX;
		}
	}

	if (std::abs(_angleY) > _maxAngleY) {
		if (_angleY > 0) {
			_angleY = _maxAngleY;
		} else {
			_angleY = -_maxAngleY;
		}
	}

	// Let all observers know that the view has changed
	notifyObservers();
}
