/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    convert.cc
 * @brief   Definition of Convert class
 * @date    2008
 *
 * This file contains the definition of Convert class, a static class
 * containing useful methods for conversions.
 *
 */

#include "convert.h"

#include <sstream>
#include <cassert>


using std::string;
using std::istringstream;
using std::ostringstream;


std::string Convert::IntToString(int n)
{
	ostringstream oss;  // the output stream for the string
	oss << n;           // insert the integer into the stream

	return oss.str();   // return the string
}


int Convert::StringToInt(const std::string& str)
{
	istringstream i(str);   // the input stream
	int x;                  // the converted number
	char c;                 // a helper character

	if (!(i >> x) || i.get(c)) {
		// if it the reading of the data type from the stream was not
		// successful or if there were some characters left in the
		// stream after the input
		assert(false);
	}

	return x;
}


std::string Convert::UnsignedToString(unsigned n)
{
	ostringstream oss;    // the output stream for the string
	oss << n;             // insert the unsigned integer into the stream

	return oss.str();     // return the string
}


unsigned Convert::StringToUnsigned(const std::string& str)
{
	istringstream i(str);  // the input stream
	unsigned x;            // the converted number
	char c;                // a helper character

	if (!(i >> x) || i.get(c)) {
		// if it the reading of the data type from the stream was not
		// successful or if there were some characters left in the
		// stream after the input
		assert(false);
	}

	return x;
}


std::string Convert::BoolToString(bool b)
{
	ostringstream oss;  // the output stream for the string
	oss << b;           // insert the bool into the stream

	return oss.str();   // return the string
}


bool Convert::StringToBool(const std::string& str)
{
	istringstream i(str);  // the input stream
	bool x;                // the converted boolean value
	char c;                // a helper character

	if (!(i >> x) || i.get(c)) {
		// if it the reading of the data type from the stream was not
		// successful or if there were some characters left in the
		// stream after the input
		assert(false);
	}

	return x;
}
