/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    convert.h
 * @brief   Declaration of Convert class
 * @date    2008
 *
 * This file contains the declaration of Convert class, a static class
 * containing useful methods for conversions.
 *
 */


#ifndef _CONVERT_H_
#define _CONVERT_H_


#include <string>


/**
 * @brief  A static class for conversions
 *
 * This is a static class that constains useful methods for various
 * conversions.
 */
class Convert
{
	private:

		// Disable both constructors, destructor and assignment operator
		Convert();
		~Convert();
		Convert(const Convert &);
		Convert & operator=(const Convert &);

	public:

		/**
		 * @brief  Converts integer to string
		 *
		 * Static method for conversion of an integer to a string
		 *
		 * @param[in]  n  The integer for the conversion
		 * @returns    The string representation of the integer
		 */
		static std::string IntToString(int n);

		/**
		 * @brief   Converts string to integer
		 *
		 * Static method for conversion of a string to an integer
		 *
		 * @param[in]  str  The string for the conversion
		 * @returns     The integer value of the string
		 */
		static int StringToInt(const std::string& str);

		/**
		 * @brief  Converts unsigned integer to string
		 *
		 * Static method for conversion of an unsigned integer to a string
		 *
		 * @param[in]  n  The unsigned integer for the conversion
		 * @returns    The string representation of the unsigned integer
		 */
		static std::string UnsignedToString(unsigned n);

		/**
		 * @brief  Converts string to unsigned integer
		 *
		 * Static method for conversion of a string to the unsigned integer
		 *
		 * @param[in]  str  The string for the conversion
		 * @returns    The unsigned integer value of the string
		 */
		static unsigned StringToUnsigned(const std::string& str);

		/**
		 * @brief  Converts bool to string
		 *
		 * Static method for conversion of a boolean value to a string
		 * @param[in]  b  The boolean value for the conversion
		 * @returns    The string representation of the boolean value
		 */
		static std::string BoolToString(bool b);

		/**
		 * @brief  Converts string to boolean value
		 *
		 * Static method for conversion of a string to a boolean value
		 *
		 * @param[in]  str  The string for the conversion
		 * @returns    The boolean value of the string
		 */
		static bool StringToBool(const std::string& str);
};

#endif
