/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    create_scene_parameters.h
 * @brief   CreateSceneParameters class declaration.
 * @date    2008
 *
 */

#ifndef _CREATE_SCENE_PARAMETERS_H_
#define _CREATE_SCENE_PARAMETERS_H_

#include <Inventor/nodes/SoSeparator.h>

#include "camera.h"
#include "game_configuration.h"

/**
 * @brief Parameters for the SceneCreator::createScene() function.
 *
 * All these attributes have to be correctly set in GUI before the Scene
 * is created by calling the SceneCreator::createScene() function.
 *
 * Uses "crate" design pattern.
 *
 * @see SceneCreator, Scene
 */
class CreateSceneParameters
{
	public:

		/// Game configuration (chosen by a user via GUI).
		GameConfiguration gameConfig;

		/// Scene root node.
		SoSeparator *sceneRoot;

		/// Camera.
		Camera *camera;

		/// Function that should be called on successfull game end.
		void (*successGameEndFunc)();

		/// Function that should be called on failed game end.
		void (*failedGameEndFunc)();

	public:

		/**
		 * @brief Default constructor.
		 */
		CreateSceneParameters();

		/**
		 * @brief Destructor.
		 */
		~CreateSceneParameters();
};

#endif
