/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    difficulty_settings.h
 * @brief   DifficultySettings class declaration.
 * @date    2008
 *
 */

#ifndef _DIFFICULTY_SETTINGS_H_
#define _DIFFICULTY_SETTINGS_H_

/**
 * @brief Game difficulty settings.
 *
 * All attributes correspond to options that a user choose when starting
 * a new game.
 *
 * Uses "crate" design pattern.
 */
class DifficultySettings
{
	public:

		/// Number of different bubble types (color, ...) in the game.
		unsigned numOfDifferentBubbles;

		/// Number of initially filled plates with bubbles.
		unsigned numOfInitiallyFilledPlates;

		/// Probability that (at the beginning) a single cell will contain
		/// a bubble [0.0 - 1.0].
		float probCellContainBubble;

		/// Rear wall speed.
		float wallSpeed;

	public:

		/**
		 * @brief Default constructor.
		 */
		DifficultySettings();

		/**
		 * @brief Destructor.
		 */
		~DifficultySettings();
};

#endif
