/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    factory_play_box_graphics.h
 * @brief   Factory that creates instances of objects derived from the PlayBoxGraphics class.
 * @date    2008
 *
 * Implementation is using "Object factory" and "Singleton" design patterns.
 */

#ifndef _FACTORIES__FACTORY_PLAYBOX_GRAPHICS_H_
#define _FACTORIES__FACTORY_PLAYBOX_GRAPHICS_H_

#include <string>

#include "../templates/factory.h"
#include "../templates/singleton.h"
#include "../play_box_graphics.h"

/**
 * @brief Factories creating concrete class instances.
 */
namespace Factories
{
	/**
	* @brief Factory that creates instances of objects derived from the PlayBoxGraphics class.
	*/
	typedef Templates::Singleton<
		Templates::Factory<
			// Type of a basic product
			PlayBoxGraphics,
			// Type of an object identifier
			std::string
		>
	> FactoryPlayBoxGraphics;

}

#endif
