/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    fading_explosion.cc
 * @brief   FadingExplosion class definition.
 * @date    2008
 *
 */

#include <cstdlib>
#include <string>

#include <Inventor/nodes/SoSphere.h>

#include "fading_explosion.h"
#include "path_functions.h"


const float FadingExplosion::FADEOFF_TIME = 2.0f;


FadingExplosion::FadingExplosion(SbColor color, Camera *camera):
	Explosion(color), _actualTime(0.0f), _camera(camera), _material(0)
{
	_camera->addObserver(this);

	// Create a material of the bubble
	_material = new SoMaterial();
	_material->diffuseColor.setValue(_color);
	_material->transparency.setValue(0.0f);
	_rootNode->addChild(_material);

	// The bubble
	SoSphere* bubble = new SoSphere();
	bubble->radius.setValue(Bubble::getRadius());
	_rootNode->addChild(bubble);
}

FadingExplosion::~FadingExplosion()
{
	_camera->deleteObserver(this);
}

FadingExplosion *FadingExplosion::clone() const
{
	return new FadingExplosion(_color, _camera);
}

void FadingExplosion::timeUpdate(float dt)
{
	if (_isActive) {
		_actualTime += dt;

		if (_actualTime <= FADEOFF_TIME) {
			_material->transparency.setValue(_actualTime / FADEOFF_TIME);
		}	else {
			_explodeDone->callableBackNotify(this);
		}
	}
}

void FadingExplosion::update(Camera* /*subject*/)
{
}

