/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    fading_explosion.h
 * @brief   FadingExplosion class declaration.
 * @date    2008
 *
 */

#ifndef _FADING_EXPLOSION_H_
#define _FADING_EXPLOSION_H_

#include <Inventor/nodes/SoRotation.h>
#include <Inventor/nodes/SoTextureCoordinate2.h>

#include "camera.h"
#include "explosion.h"
#include "templates/observer.h"

/**
 * @brief Fading explosion effect.
 *
 * Reference object (cannot be copied).
 */
class FadingExplosion: public Explosion, public Templates::Observer<Camera>
{
	private:

		/// Actual time during the explosion.
		float _actualTime;

		/// Camera.
		Camera *_camera;

		/// The material of the fading bubble
		SoMaterial* _material;

	public:

		/// The time for which the bubble fades off
		static const float FADEOFF_TIME;

	private:

		// Disable copy constructor and assignment operator
		FadingExplosion(const FadingExplosion &);
		FadingExplosion & operator=(const FadingExplosion &);

	public:

		/**
		 * @brief Constructor.
		 *
		 * @param[in] color  Explosion color.
		 * @param[in] camera Main camera.
		 *
		 * Camera is needed bacuase this implementation needs it to adjust
		 * the explosion image.
		 */
		FadingExplosion(SbColor color, Camera *camera);

		/**
		 * @brief Destructor.
		 */
		virtual ~FadingExplosion();

		// Override
		FadingExplosion *clone() const;

		// Override
		virtual void timeUpdate(float dt);

		// Override
		virtual void update(Camera *subject);
};

#endif

