/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    fire_explosion.h
 * @brief   FireExplosion class declaration.
 * @date    2008
 *
 */

#ifndef _FIRE_EXPLOSION_H_
#define _FIRE_EXPLOSION_H_

#include <Inventor/nodes/SoRotation.h>
#include <Inventor/nodes/SoTextureCoordinate2.h>

#include "camera.h"
#include "explosion.h"
#include "templates/observer.h"

/**
 * @brief Fire explosion effect.
 *
 * Reference object (cannot be copied).
 */
class FireExplosion: public Explosion, public Templates::Observer<Camera>
{
	private:

		/// This textureIndex value means that the index is not set.
		static const int TEXTURE_INDEX_NOT_SET = -1;

		/// Minimal texture index.
		static const int TEXTURE_INDEX_MIN = 0;

		/// Maximal texture index.
		static const int TEXTURE_INDEX_MAX = 15;

		/// Actual time during the explosion.
		float _actualTime;

		/// Current texture index.
		int _textureIndex;

		/// Explosion image (animated texture) separator.
		SoSeparator *_billboard;

		/// Texture (image) coordinate.
		SoTextureCoordinate2 *_textureCoord;

		/// Camera.
		Camera *_camera;

		/// Rotation in the X axis.
		SoRotationXYZ *_rotX;

		/// Rotation in the Y axis.
		SoRotationXYZ *_rotY;

	private:

		// Disable copy constructor and assignment operator
		FireExplosion(const FireExplosion &);
		FireExplosion & operator=(const FireExplosion &);


		/**
		 * @brief Returns random texture file name from available textures.
		 */
		static const char *getRandomTextureFileName();

	public:

		/**
		 * @brief Constructor.
		 *
		 * @param[in] color  Explosion color.
		 * @param[in] camera Main camera.
		 *
		 * Camera is needed bacuase this implementation needs it to adjust
		 * the explosion image.
		 */
		FireExplosion(SbColor color, Camera *camera);

		/**
		 * @brief Destructor.
		 */
		virtual ~FireExplosion();

		// Override
		FireExplosion *clone() const;

		// Override
		virtual void timeUpdate(float dt);

		// Override
		virtual void update(Camera *subject);
};

#endif
