/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    game_configuration.h
 * @brief   GameConfiguration class declaration.
 * @date    2008
 *
 */

#ifndef _GAME_CONFIGURATION_H_
#define _GAME_CONFIGURATION_H_

#include <string>

#include "difficulty_settings.h"

/**
 * @brief Raw game configuration.
 *
 * All attributes correspond to options that a user choose when starting
 * a new game.
 *
 * Uses "crate" design pattern.
 */
class GameConfiguration
{
	public:

		/// Concrete environment ID (how the environment should look).
		std::string environmentTypeId;

		/// Concrete avatar ID (how the avatar should look).
		std::string avatarTypeId;

		/// Concrete play box graphics ID (how the play box should look).
		std::string playBoxGraphicsTypeId;

		/// Concrete play box physics ID (how the play box should behave).
		std::string playBoxPhysicsTypeId;

		/// Difficulty settings.
		DifficultySettings difficultySettings;

	public:

		/**
		 * @brief Default constructor.
		 */
		GameConfiguration();

		/**
		 * @brief Destructor.
		 */
		~GameConfiguration();
};

#endif
