/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    graphical_node.h
 * @brief   Header file for the GraphicalNode abstract class
 * @date    2008
 *
 * Header file for the GraphicalNode abstract class, the class providing
 * biding to the OpenInventor.
 */

#ifndef _GRAPHICAL_NODE_H_
#define _GRAPHICAL_NODE_H_

#include <Inventor/nodes/SoSeparator.h>

/**
 * @brief   Abstract class providing binding to the OpenInventor
 *
 * Abstract class providing binding to the OpenInventor. This class should be
 * inherited by every class, that has a graphical representation in the
 * OpenInventor scene graph.
 */
class GraphicalNode
{
	private:

		// Disable copy constructor and assignment operator
		GraphicalNode(const GraphicalNode &);
		GraphicalNode & operator=(const GraphicalNode &);

	protected:

		/// Root node of the OpenInventor graphical representation of the object
		SoGroup* _rootNode;

	protected:

		/**
		 * @brief Default constructor
		 */
		GraphicalNode();

	public:

		/**
		 * @brief Destructor
		 */
		virtual ~GraphicalNode() =0;

		/**
		 * @brief  Returns the root node of the OpenInventor graphical
		 *         representation of the object
		 *
		 * @return   The root node of the OpenInventor graphical representation
		 *           of the object
		 */
		SoGroup* getRootNode() { return _rootNode; }
};

#endif
