/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    game_menu.h
 * @brief   GameMenu class declaration.
 * @date    2008
 *
 */


#ifndef _GUI__GAME_MENU_H_
#define _GUI__GAME_MENU_H_

#include <qwidget.h>
#include <qlayout.h>
#include <qcombobox.h>
#include <qslider.h>

#include "../game_configuration.h"

/**
 * @brief Graphical user interface.
 */
namespace GUI
{
	class GameMenu;
}

/**
 * @brief Game menu.
 *
 * Creates game menu.
 */
class GUI::GameMenu: public QWidget
{
	private:
		// Allows to contain signals and/or slots
		Q_OBJECT

		/// Grid.
		QGridLayout *_grid;

		/// Environment select list.
		QComboBox *_environmentCB;

		/// Avatar select list.
		QComboBox *_avatarCB;

		/// Play box graphics select list.
		QComboBox *_playBoxGraphicsCB;

		/// Play box physics select list.
		QComboBox *_playBoxPhysicsCB;

		/// Difficulty select list.
		QComboBox *_difficultyCB;

		/// Number of different bubbles select list.
		QSlider *_numberOfDifferentBubblesSL;

		/// Number of filled layers
		QSlider *_numberOfFilledLayersSL;

		/// Bubbles density in one layer
		QSlider *_bubblesDensitySL;

		/// Rear wall speed
		QSlider *_rearWallSpeedSL;

	public:

		/**
		 * @brief Default constructor.
		 *
		 * @param[in]  parent The parent widget.
		 * @param[in]  name   The name of the new created widget.
		 */
		GameMenu(QWidget *parent = 0, const char *name = 0);

		/**
		 * @brief Collects all information from this class in GameConfiguration.
		 */
		GameConfiguration getGameConfig();

	public slots:

		/**
		 * @brief A method to be called when difficulty is changed.
		 */
		void difficultyChanged();
};

#endif
