/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    main_window.h
 * @brief   MainWindow class declaration. Top level window.
 * @date    2008
 *
 */

#ifndef _GUI__MAIN_WINDOW_H
#define _GUI__MAIN_WINDOW_H

#include <qlayout.h>

#include "game_menu.h"

/**
 * @brief Graphical user interface.
 */
namespace GUI
{
	class MainWindow;
}

/**
 * @brief Main window.
 *
 * This class is used to create the whole application window.
 */
class GUI::MainWindow: public QWidget
{
	private:
		// Allows to contain signals and/or slots
		Q_OBJECT

		/// Grid pointer. Allows to chagne whats shown.
		QGridLayout *_grid;

		/// The mainWidget is whats seen under the main menu.
		QWidget *_mainWidget;

		/// used to call gameMenu->getGameConfig().
		GUI::GameMenu *_gameMenu;

	public:
		/**
		 * @brief Default constructor.
		 *
		 * @param[in]  parent The parent widget.
		 * @param[in]  name   The name of the new created widget.
		 */
		MainWindow(QWidget *parent = 0, const char *name = 0);

		/**
		 * @brief A method to be called when the mainWidget is changed.
		 *
		 * @param[in]  w  The new widget to be seen in MainWindow.
		 */
		void changeMainWidget(QWidget *w);

		/**
		 * @brief A method to be called when the player wins.
		 */
		void gameWin();

		/**
		 * @brief A method to be called when the player loses.
		 */
		void gameLose();

	public slots:

		/**
		 * @brief A method to be called when Help->Rules is clicked.
		 */
		void showHelpRules();

		/**
		 * @brief A method to be called when Help->About is clicked.
		 */
		void showHelpAbout();

		/**
		 * @brief A method to be called when Game->New is clicked.
		 */
		void showGameNew();

		/**
		 * @brief A method to be called when Game->New->Start is clicked.
		 */
		void startGameNew();
};

#endif
