/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    path_functions.cc
 * @brief   PathFunctions class definition.
 * @date    2008
 *
 */

#include <unistd.h>

#include "path_functions.h"

using std::string;

namespace
{
	// Size of a buffer
	const unsigned BUFFER_SIZE = 4096;
}

string PathFunctions::getExecutablePath()
{
	char buffer[BUFFER_SIZE];
	int result = readlink("/proc/self/exe", buffer, sizeof(buffer) - sizeof(char));
	if (result != -1) {
		// readlink() don't 0-terminate the buffer
		buffer[result] = '\0';

		return string(buffer);
	}

	// Cannot find the path
	return string();
}

string PathFunctions::getExecutableDirectory()
{
	string executablePath = getExecutablePath();
	if (executablePath.size() > 0) {
		// Remove the name of the executable from the end of the path

		// Because executablePath is an absolute path, there should be
		// at least one / in it
		string::size_type lastSlashPos = executablePath.find_last_of("/");
		if (lastSlashPos != string::npos) {
			// Include the last slash
			return string(executablePath, 0, lastSlashPos + 1);
		}
	}

	// Cannot find the directory
	return string();
}

bool PathFunctions::fileExists(const string & filePath)
{
	// access() returns 0 on success
	return access(filePath.c_str(), R_OK) == 0;
}

string PathFunctions::createProperFilePath(const string & filePath)
{
	if (fileExists(filePath)) {
		// Ok, nothing to do here...
		return filePath;
	}

	// Original file doesn't exist, so try prepand the running exectuable
	// binary directory path
	string changedFilePath = getExecutableDirectory() + filePath;
	if (fileExists(changedFilePath)) {
		// Changed file path is fine, so return it
		return changedFilePath;
	}

	// No luck with finding a proper path, so return the original one
	return filePath;
}
