/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    path_functions.h
 * @brief   PathFunctions class declaration.
 * @date    2008
 *
 */


#ifndef _PATH_FUNCTIONS_H_
#define _PATH_FUNCTIONS_H_

#include <string>

/**
 * @brief Various path functions.
 *
 * Uses "library class" (aka "static helper") design pattern.
 */
class PathFunctions
{
	private:

		// Disable both constructors, destructor and assignment operator
		PathFunctions();
		~PathFunctions();
		PathFunctions(const PathFunctions &);
		PathFunctions & operator=(const PathFunctions &);

	public:

		/**
		 * @brief Returns absolute path of the current executable.
		 *
		 * If it fails to find the path, it returns an empty string.
		 */
		static std::string getExecutablePath();

		/**
		 * @brief Returns absolute path of a directory where the current
		 *        executable is located (ended by '/').
		 *
		 * If it fails to find the directory, it returns an empty string.
		 */
		static std::string getExecutableDirectory();

		/**
		 * @brief Returns true if the selected file exists, false otherwise.
		 *
		 * @param filePath File to be tested.
		 */
		static bool fileExists(const std::string & filePath);

		/**
		 * @brief Converts selected file path to a "proper" one (see description for more info).
		 *
		 * @param filePath File path to be tested.
		 *
		 * This function should be called before opening a file from the application,
		 * because of possibility that the user will run the application from another
		 * path (insted of running it directly from the application directory).
		 * If the selected file pah exists, it returns it without change, but if
		 * it doesn't exist it will try to get existence of the file according
		 * to the application directory.
		 * If it fails now, it will return original file path, so you have to test
		 * the existence of the file anyway (it's more suitable for error messages
		 * and exceptions handling).
		 */
		static std::string createProperFilePath(const std::string & filePath);
};

#endif
