/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    play_box_graphics.h
 * @brief   PlayBoxGraphics class declaration.
 * @date    2008
 *
 */

#ifndef _PLAY_BOX_GRAPHICS_H_
#define _PLAY_BOX_GRAPHICS_H_

#include <Inventor/nodes/SoTranslation.h>

#include "graphical_node.h"
#include "time_updateable.h"

/**
 * @brief Graphical properties of a play box (abstract class).
 *
 * Reference object (cannot be copied).
 */
class PlayBoxGraphics: public TimeUpdateable, public GraphicalNode
{
	private:

		// Disable copy constructor and assignment operator
		PlayBoxGraphics(const PlayBoxGraphics &);
		PlayBoxGraphics & operator=(const PlayBoxGraphics &);

		/**
		 * @brief A virtual method that creates walls
		 *
		 * This methods creates the four PlayBoxGraphics side walls. It is to be
		 * overriden by each descendant of this abstract class.
		 *
		 * @return	SoGroup with play box walls
		 */
		virtual SoGroup* createWalls() =0;

		/**
		 * @brief A virtual method that creates the back wall
		 *
		 * This methods creates the back wall of the PlayBoxGraphics. It is to be
		 * overriden by each descendant of this abstract class.
		 *
		 * @return	SoGroup with back wall
		 */
		virtual SoGroup* createBackWall() =0;

	protected:

		/// The translation of the back wall
		SoTranslation* _wallTranslation;

	public:

		/**
		 * @brief Default constructor.
		 */
		PlayBoxGraphics();

		/**
		 * @brief Destructor.
		 */
		virtual ~PlayBoxGraphics();

		/**
		 * @brief  A method to be called when the wall offset changes
		 *
		 * This method is to be called from PlayField when the wall offset
		 * changes. The argument denotes the new offset of the wall.
		 *
		 * @param[in]  newOffset  The new offset of the wall
		 */
		virtual void moveWall(float newOffset);
};

#endif
