/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    play_box.cc
 * @brief   PlayBoxPhysics class definition.
 * @date    2008
 *
 */

#include <cstdlib>

#include <Inventor/SbLinear.h>

#include "play_box_physics.h"
#include "play_field.h"

namespace
{
	// Half of the side of the play box (radius of the bubble is extracted
	// to save this operation later)
	const float BOX_SIDE_HALF = PlayField::getSizeHalfSize() -
		Bubble::getRadius();
}

PlayBoxPhysics::PlayBoxPhysics()
{
}

PlayBoxPhysics::~PlayBoxPhysics()
{
}

void PlayBoxPhysics::moveBubble(Bubble* bubble, float distance)
{
	bubble->timeUpdate(distance);

	float x = bubble->getPosition()[0];
	float y = bubble->getPosition()[1];

	if (x > BOX_SIDE_HALF) {
		fixLeftWallCollision(bubble, BOX_SIDE_HALF);
	} else if ((-x) > BOX_SIDE_HALF) {
		fixRightWallCollision(bubble, -BOX_SIDE_HALF);
	}

	if (y > BOX_SIDE_HALF) {
		fixTopWallCollision(bubble, BOX_SIDE_HALF);
	} else if ((-y) > BOX_SIDE_HALF) {
		fixBottomWallCollision(bubble, -BOX_SIDE_HALF);
	}
}

