/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    play_box_physics.h
 * @brief   PlayBoxPhysics class declaration.
 * @date    2008
 *
 */

#ifndef _PLAY_BOX_PHYSICS_H_
#define _PLAY_BOX_PHYSICS_H_

#include "graphical_node.h"
#include "time_updateable.h"
#include "bubble.h"

/**
 * @brief Graphical properties of a play box (abstract class).
 *
 * Reference object (cannot be copied).
 */
class PlayBoxPhysics: public TimeUpdateable, public GraphicalNode
{
	private:

		// Disable copy constructor and assignment operator
		PlayBoxPhysics(const PlayBoxPhysics &);
		PlayBoxPhysics & operator=(const PlayBoxPhysics &);

		/**
		 * @brief Fixes a collision with left wall
		 *
		 * @param[in]  bubble     Pointer to a bubble which has caused a collision
		 * @param[in]  borderPos  Position of the wall which the bubble collided
		 *
		 * Implements template method design pattern
		 */
		virtual void fixLeftWallCollision(Bubble* bubble, float borderPos) =0;

		/**
		 * @brief Fixes a collision with right wall
		 *
		 * @param[in]  bubble     Pointer to a bubble which has caused a collision
		 * @param[in]  borderPos  Position of the wall which the bubble collided
		 *
		 * Implements template method design pattern
		 */
		virtual void fixRightWallCollision(Bubble* bubble, float borderPos) =0;

		/**
		 * @brief Fixes a collision with top wall
		 *
		 * @param[in]  bubble     Pointer to a bubble which has caused a collision
		 * @param[in]  borderPos  Position of the wall which the bubble collided
		 *
		 * Implements template method design pattern
		 */
		virtual void fixTopWallCollision(Bubble* bubble, float borderPos) =0;

		/**
		 * @brief Fixes a collision with bottom wall
		 *
		 * @param[in]  bubble     Pointer to a bubble which has caused a collision
		 * @param[in]  borderPos  Position of the wall which the bubble collided
		 *
		 * Implements template method design pattern
		 */
		virtual void fixBottomWallCollision(Bubble* bubble, float borderPos) =0;

	public:

		/**
		 * @brief Default constructor.
		 */
		PlayBoxPhysics();

		/**
		 * @brief Destructor.
		 */
		virtual ~PlayBoxPhysics();

		/**
		 * @brief Moves the bubble
		 *
		 * @param[in]  bubble    Pointer to a bubble which should be moved
		 * @param[in]  distance  Length of which the bubble should be moved
		 *
		 * Moves the flying bubble to a new position
		 */
		void moveBubble(Bubble* bubble, float distance);
};

#endif
