/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    random_play_box_physics.cc
 * @brief   RandomPlayBoxPhysics class definition.
 * @date    2008
 *
 */

#include <cstdlib>
#include <string>

#include <Inventor/SbLinear.h>

#include "random_play_box_physics.h"
#include "factories/factory_play_box_physics.h"

void RandomPlayBoxPhysics::fixHorizontalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	float correction = 2 * (position[1] - borderPos);
	bubble->setPosition(SbVec3f(
				position[0], position[1] - correction, position[2]));

	// Correct the motion vector
	const SbVec3f& motionVector = bubble->getMotionVector();
	const float randNums[] = {std::rand() / (RAND_MAX + 1.0),
			std::rand() / (RAND_MAX + 1.0)};
	bubble->setMotionVector(SbVec3f(
				motionVector[0] + randNums[0] * (randNums[1] > 0.5 ? 1 : -1),
				-motionVector[1],
				motionVector[2]));
}

void RandomPlayBoxPhysics::fixVerticalWallCollision(Bubble* bubble, float borderPos)
{
	// Correct the position
	const SbVec3f& position = bubble->getPosition();
	float correction = 2 * (position[0] - borderPos);
	bubble->setPosition(SbVec3f(
				position[0] - correction, position[1], position[2]));

	// Correct the motion vector
	const SbVec3f& motionVector = bubble->getMotionVector();
	const float randNums[] = {std::rand() / (RAND_MAX + 1.0),
			std::rand() / (RAND_MAX + 1.0)};
	bubble->setMotionVector(SbVec3f(
				-motionVector[0],
				motionVector[1] + randNums[0] * (randNums[0] < 0.5 ? 1 : -1),
				motionVector[2]));
}

void RandomPlayBoxPhysics::fixLeftWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void RandomPlayBoxPhysics::fixRightWallCollision(Bubble* bubble, float borderPos)
{
	fixVerticalWallCollision(bubble, borderPos);
}

void RandomPlayBoxPhysics::fixTopWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

void RandomPlayBoxPhysics::fixBottomWallCollision(Bubble* bubble, float borderPos)
{
	fixHorizontalWallCollision(bubble, borderPos);
}

RandomPlayBoxPhysics::RandomPlayBoxPhysics()
{
}

RandomPlayBoxPhysics::~RandomPlayBoxPhysics()
{
}

void RandomPlayBoxPhysics::timeUpdate(float /*dt*/)
{
	// Do nothing
}

// Functions and constants needed by Factories::FactoryPlayBoxPhysics
namespace
{
	// RandomPlayBoxPhysics identifier for the play box physics factory
	const std::string RANDOM_PLAY_BOX_PHYSICS_ID = "Random";

	// Function that returns an instance of the RandomPlayBoxPhysics class
	PlayBoxPhysics *getRandomPlayBoxPhysicsInstance()
	{
		return new RandomPlayBoxPhysics::RandomPlayBoxPhysics();
	}

	// Register the selected play box physics at the play box physics factory
	const bool RANDOM_PLAY_BOX_PHYSICS_REGISTERED = Factories::FactoryPlayBoxPhysics::instance().
		registerObject(RANDOM_PLAY_BOX_PHYSICS_ID, getRandomPlayBoxPhysicsInstance);
}
