/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    scene.cc
 * @brief   Scene class definition.
 * @date    2008
 *
 */

#include <Inventor/nodes/SoTransparencyType.h>

#include "scene.h"
#include "avatar.h"
#include "environment.h"
#include "play_box_graphics.h"
#include "play_box_physics.h"

Scene::Scene(SceneConfiguration sceneConfig):
	_sceneConfig(sceneConfig), _playField(0)
{
	_rootNode = _sceneConfig.rootNode;

	// set the transparency type
	SoTransparencyType* trans = new SoTransparencyType();
	//trans->value.setValue(SoTransparencyType::DELAYED_ADD);
	trans->value.setValue(SoTransparencyType::SORTED_OBJECT_SORTED_TRIANGLE_BLEND);
	_rootNode->addChild(trans);

	// Add camera
	_rootNode->addChild(_sceneConfig.camera->getRootNode());

	// Add environment
	_rootNode->addChild(_sceneConfig.environment->getRootNode());

	// Register avatar at the camera to receive updates
	_sceneConfig.camera->addObserver(_sceneConfig.avatar);

	// Create a playfield
	_playField = new PlayField(_sceneConfig);
	_rootNode->addChild(_playField->getRootNode());
}

Scene::~Scene()
{
	delete _playField;
	_playField = 0;

	// Also delete everything (but camera, which was created in GUI) from
	// the scene configuration (these were allocated in
	// the SceneCreator::createScene(), but they cannot be deleted there)
	delete _sceneConfig.environment;
	_sceneConfig.environment = 0;
	delete _sceneConfig.avatar;
	_sceneConfig.avatar = 0;
	delete _sceneConfig.playBoxGraphics;
	_sceneConfig.playBoxGraphics = 0;
	delete _sceneConfig.playBoxPhysics;
	_sceneConfig.playBoxPhysics = 0;
}

void Scene::timeUpdate(float dt)
{
	// Forward time update
	_playField->timeUpdate(dt);
}

void Scene::fire()
{
	// Forward fire event
	_playField->fire();
}
