/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    scene.h
 * @brief   Scene class declaration.
 * @date    2008
 *
 */

#ifndef _SCENE_H_
#define _SCENE_H_

#include "graphical_node.h"
#include "play_field.h"
#include "scene_configuration.h"
#include "time_updateable.h"

/**
 * @brief Main scene.
 *
 * Reference object (cannot be copied).
 */
class Scene: public TimeUpdateable, public GraphicalNode
{
	private:

		/// Scene configuration.
		SceneConfiguration _sceneConfig;

		/// Play field.
		PlayField *_playField;

	private:

		// Disable copy constructor and assignment operator
		Scene(const Scene &);
		Scene & operator=(const Scene &);

	public:

		/**
		 * @brief Constructor.
		 *
		 * @param[in] sceneConfig Scene configuration.
		 */
		Scene(SceneConfiguration sceneConfig);

		/**
		 * @brief Destructor.
		 */
		~Scene();

		// Override
		virtual void timeUpdate(float dt);

		/**
		 * @brief Fire event.
		 *
		 * This method should be called when a user has fired (by clicking
		 * a left mouse button etc.).
		 */
		void fire();
};

#endif
