/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    scene_configuration.h
 * @brief   SceneConfiguration class declaration.
 * @date    2008
 *
 */


#ifndef _SCENE_CONFIGURATION_H_
#define _SCENE_CONFIGURATION_H_

#include <Inventor/nodes/SoSeparator.h>

#include "environment.h"
#include "camera.h"
#include "avatar.h"
#include "difficulty_settings.h"

class Environment;
class Avatar;
class PlayBoxGraphics;
class PlayBoxPhysics;
class Camera;

/**
 * @brief Scene configuration.
 *
 * All these attributes have to be set correctly before a Scene is created.
 * Furthermore, Scene will also pass an instance of this class to its
 * subcomponents, like PlayField.
 *
 * Uses "crate" design pattern.
 *
 * @see Scene, PlayField
 */
class SceneConfiguration
{
	public:

		/// Scene root node.
		SoSeparator *rootNode;

		/// Strategy object that represents Scene look.
		Environment *environment;

		/// Strategy object that represents Avatar look.
		Avatar *avatar;

		/// Strategy object that represents PlayBox look.
		PlayBoxGraphics *playBoxGraphics;

		/// Strategy object that represents PlayBox behaviour.
		PlayBoxPhysics *playBoxPhysics;

		/// Camera.
		Camera *camera;

		/// Function that should be called on successfull game end.
		void (*successGameEndFunc)();

		/// Function that should be called on failed game end.
		void (*failedGameEndFunc)();

		/// Game difficulty settings.
		DifficultySettings gameDifficulty;

	public:

		/**
		 * @brief Default constructor.
		 */
		SceneConfiguration();

		/**
		 * @brief Destructor.
		 */
		~SceneConfiguration();
};

#endif
