/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    scene_creator.cc
 * @brief   SceneCreator class definition.
 * @date    2008
 *
 */

#include <Inventor/nodes/SoSeparator.h>

#include "scene_creator.h"
#include "scene_configuration.h"
#include "camera.h"
#include "game_configuration.h"
#include "factories/factory_environment.h"
#include "factories/factory_avatar.h"
#include "factories/factory_play_box_graphics.h"
#include "factories/factory_play_box_physics.h"

using namespace Factories;

Scene *SceneCreator::createScene(const CreateSceneParameters & params)
{
	SceneConfiguration sceneConfig;
	GameConfiguration gameConfig(params.gameConfig);

	sceneConfig.rootNode = params.sceneRoot;
	sceneConfig.camera = params.camera;
	sceneConfig.environment = FactoryEnvironment::instance().createObject(
		gameConfig.environmentTypeId);
	sceneConfig.avatar = FactoryAvatar::instance().createObject(
		gameConfig.avatarTypeId);
	sceneConfig.playBoxGraphics = FactoryPlayBoxGraphics::instance().createObject(
		gameConfig.playBoxGraphicsTypeId);
	sceneConfig.playBoxPhysics = FactoryPlayBoxPhysics::instance().createObject(
		gameConfig.playBoxPhysicsTypeId);
	sceneConfig.gameDifficulty = gameConfig.difficultySettings;
	sceneConfig.successGameEndFunc = params.successGameEndFunc;
	sceneConfig.failedGameEndFunc = params.failedGameEndFunc;

	return new Scene(sceneConfig);
}
