/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    scene_creator.h
 * @brief   SceneCreator class declaration.
 * @date    2008
 *
 */

#ifndef _SCENE_CREATOR_H_
#define _SCENE_CREATOR_H_

#include <Inventor/nodes/SoSeparator.h>

#include "scene.h"
#include "create_scene_parameters.h"

/**
 * @brief Main scene creator.
 *
 * This class is used to create an instance of a Scene from selected parameters.
 *
 * Uses "library class" (aka "static helper") design pattern.
 */
class SceneCreator
{
	private:

		// Disable both constructors, destructor and assignment operator
		SceneCreator();
		~SceneCreator();
		SceneCreator(const SceneCreator &);
		SceneCreator & operator=(const SceneCreator &);

	public:

		/**
		 * @brief Creates a scene from given parameters.
		 *
		 * @param[in]  params Scene parameters.
		 * @return     Created scene.
		 */
		static Scene *createScene(const CreateSceneParameters & params);
};

#endif
