/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    snowman_avatar.h
 * @brief   Header file for the snowman avatar
 * @date    2008
 *
 * Header file for the snowman avatar.
 */

#ifndef _SNOWMAN_AVATAR_H_
#define _SNOWMAN_AVATAR_H_

#include <Inventor/engines/SoElapsedTime.h>

#include "avatar.h"

/**
 * @brief Snowman avatar.
 */
class SnowmanAvatar: public Avatar
{
	private:

		/// Enumeration of snowman avatar states
		enum State
		{
			STOPPED,   /// the hammer is stopped
			PREFIRE,   /// the hammer is moving, but has not hit the bubble yet
			POSTFIRE   /// the hammer is moving and has already hit the bubble
		};

		/// Initial rotation of the bubble hammer
		static const float INITIAL_HAMMER_ROT;

		/// Rotation in the X axis
		SoRotationXYZ *_rotX;

		/// Rotation in the Y axis
		SoRotationXYZ *_rotY;

		/// The timer used for hammer movement
		SoElapsedTime* _hammerTimer;

		/// The output time of the _hammerTimer
		SoSFFloat* _timerTimeOut;

		/// The state of the avatar
		State _state;

		/// Object on which the "action performed" method should be called when
		/// the bubble-firing sequence is completed
		Templates::CallableBack<Avatar>* _fireDone;

	private:

		// Disable copy constructor and assignment operator
		SnowmanAvatar(const SnowmanAvatar &);
		SnowmanAvatar & operator=(const SnowmanAvatar &);

	public:

		/**
		 * @brief  Default constructor
		 */
		SnowmanAvatar();

		/**
		 * @brief  Destructor.
		 */
		virtual ~SnowmanAvatar();

		// Override
		virtual void timeUpdate(float dt);

		// Override
		virtual void update(Camera* subject);

		// Override
		virtual void fire(Templates::CallableBack<Avatar>* fireDone);
};

#endif
