/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    callable_back.h
 * @brief   Implementation of a "callable back" design pattern.
 * @date    2008
 *
 */

#ifndef _TEMPLATES__CALLABLE_BACK_H_
#define _TEMPLATES__CALLABLE_BACK_H_

/**
 * @brief All project templates.
 */
namespace Templates
{
	template <class T>
	class CallableBack;
}

/**
 * @brief Implementation of a "callable back" design pattern.
 *
 * Implements "callable back" design pattern - allows creation of a function
 * with an additional parameter of type @code CallableBack *obj @endcode,
 * so that the function calls @code obj->callableBackNotify(this) @endcode when
 * some specified action is successfully performed.
 */
template <class T>
class Templates::CallableBack
{
	public:

		/**
		 * @brief Default constructor.
		 */
		CallableBack() { }

		/**
		 * @brief Destructor.
		 */
		virtual ~CallableBack() { }

		/**
		 * @brief Subject performed action on which the callback was defined.
		 *
		 * @param[in] subject Object that perfmored the action.
		 */
		virtual void callableBackNotify(T *subject) =0;
};

#endif
