/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    observer.h
 * @brief   Implementation of a generic typed observer (Observer class).
 * @date    2008
 *
 * Implementation is based on http://kelpi.com/script/d73d5b.
 */

#ifndef _TEMPLATES__OBSERVER_H_
#define _TEMPLATES__OBSERVER_H_

/**
 * @brief All project templates.
 */
namespace Templates
{
	template <class T>
	class Observer;
}

/**
 * @brief Implementation of a generic typed observer (observer part).
 *
 * Implements "observer" design pattern.
 *
 * Usage:
 *
 * @code
 * class ViewController: public Observer<View>
 * {
 *     public:
 *         ViewController() {}
 *         ~ViewController() {}
 *         void update(View * subject)
 *         {
 *             std::cout << subject->getName() << " has changed." << std::endl;
 *         }
 * };
 * @endcode
 *
 * @see Observable
 */
template <class T>
class Templates::Observer
{
	public:

		/**
		 * @brief Default constructor.
		 */
		Observer() { }

		/**
		 * @brief Destructor.
		 */
		virtual ~Observer() { }

		/**
		 * @brief Observable object changed its state.
		 *
		 * @param[in] subject Observable object.
		 *
		 * This method is a reaction to the observable object (\a arg) state change.
		 */
		virtual void update(T *subject) =0;
};

#endif
