/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    singleton.h
 * @brief   Implementation of a generic singleton.
 * @date    2008
 *
 */

#ifndef _TEMPLATES__SINGLETON_H_
#define _TEMPLATES__SINGLETON_H_

/**
 * @brief All project templates.
 */
namespace Templates
{
	template <class T>
	class Singleton;
}

/**
 * @brief Implementation of a generic singleton.
 *
 * Implements "singleton" design pattern - it is used to restrict instantiation
 * of a class to one object only.
 */
template <class T>
class Templates::Singleton
{
	private:

		// Disable both constructors, destructor and assignment operator
		Singleton();
		~Singleton();
		Singleton(const Singleton &);
		Singleton & operator=(const Singleton &);

	public:

		/**
		 * @brief Returns instance of the holding object.
		 *
		 * This function always returns a reference to the same object.
		 */
		static T & instance()
		{
			// This variant of returning static variable has a big advantage -
			// you don't have to care about destruction of the holding object
			// (if it was using dynamic allocation or it was declared static
			// as a private variable).
			// Sometimes it's called "Meyer's singleton", according to the author.
			static T instance;
			return instance;
		}
};

#endif
