/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    time_updateable.h
 * @brief   TimeUpdateable class declaration.
 * @date    2008
 *
 */

#ifndef _TIME_UPDATEABLE_H_
#define _TIME_UPDATEABLE_H_

/**
 * @brief Interface for time updateable classes.
 *
 * Each class that is updateable in time must implement this interface.
 */
class TimeUpdateable
{
	protected:

		/**
		 * @brief Default constructor.
		 */
		TimeUpdateable() { }

	public:

		/**
		 * @brief Destructor.
		 */
		virtual ~TimeUpdateable() { }

		/**
		 * @brief Timer value change event occured.
		 *
		 * This method is called on each timer value change.
		 *
		 * @param[in] dt Time difference between the last call (delta).
		 */
		virtual void timeUpdate(float dt) =0;
};

#endif
