/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    tunnel_play_box_graphics.h
 * @brief   TunnelPlayBoxGraphics class declaration.
 * @date    2008
 *
 */

#ifndef _TUNNEL_PLAY_BOX_GRAPHICS_H_
#define _TUNNEL_PLAY_BOX_GRAPHICS_H_

#include <Inventor/SbColor4f.h>

#include "play_box_graphics.h"

/**
 * @brief Tunnel play box graphics.
 *
 * The graphics representation of the play box that resembles tunnel. Reference object
 * (cannot be copied).
 */
class TunnelPlayBoxGraphics: public PlayBoxGraphics
{
	private:

		/// The start colour of the tunnel wall
		static const SbColor4f TUNNEL_COLOUR_START;

		/// The end colour of the tunnel wall
		static const SbColor4f TUNNEL_COLOUR_END;

		/// The coordinates of the wall texture
		SoTextureCoordinate2* _textureCoord;

		/// Offset of the wall texture
		float _textureOffset;

	private:

		// Disable copy constructor and assignment operator
		TunnelPlayBoxGraphics(const TunnelPlayBoxGraphics &);
		TunnelPlayBoxGraphics & operator=(const TunnelPlayBoxGraphics &);

		// override
		virtual SoGroup* createWalls();

		// override
		virtual SoGroup* createBackWall();

	public:

		/**
		 * @brief Default constructor.
		 */
		TunnelPlayBoxGraphics();

		/**
		 * @brief Destructor.
		 */
		virtual ~TunnelPlayBoxGraphics();

		// Override
		virtual void timeUpdate(float dt);
};

#endif

