/**
 *  Project:  PGR 2008
 *  Authors:  Ondrej Lengal,   xlenga00@stud.fit.vutbr.cz
 *            Libor Polcak,    xpolca03@stud.fit.vutbr.cz
 *            Boris Prochazka, xproch63@stud.fit.vutbr.cz
 *            Petr Zemek,      xzemek02@stud.fit.vutbr.cz
 *
 * @file    wire_environment.h
 * @brief   WireEnvironment class declaration.
 * @date    2008
 *
 */

#ifndef _WIRE_ENVIRONMENT_H_
#define _WIRE_ENVIRONMENT_H_

#include "environment.h"

/**
 * @brief Wire game environment.
 *
 * Reference object (cannot be copied).
 */
class WireEnvironment: public Environment
{
	private:

		// Disable copy constructor and assignment operator
		WireEnvironment(const WireEnvironment &);
		WireEnvironment & operator=(const WireEnvironment &);

	public:

		/**
		 * @brief Default constructor.
		 */
		WireEnvironment();

		/**
		 * @brief Destructor.
		 */
		~WireEnvironment();

	private:

		/**
		 * @brief Returns a wire attached to the SoSeparator
		 *
		 * @param[in]  colour  Colour of the wire
		 * @param[in]  translation  Translation of the wire
		 * @param[in]  angleX  X axis rotation
		 * @param[in]  angleY  Y axis rotation
		 * @param[in]  angleZ  Z axis rotation
		 *
		 * @returns SoSeparator with the wire
		 */
		SoSeparator* createWire(const SbColor& colour, const SbVec3f& translation,
				float angleX, float angleY, float angleZ);

	public:

		// Override
		virtual void timeUpdate(float dt);
};

#endif
